==> portal-contribuinte-3.125.1.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/integracaocontabil/patrimonial/consulta-estorno-acrescimos-parcelamentos-para-proxima-subdivida.sql <==
select tp.entidade,
       tep.dataestorno as datamovimentacao,
       tr.receita as tributo,
       tr.descricao as descricaotributo,
       tr.tiporeceita as tipotributo,
       case
           when tr.classificacao = 'F'
               then 'J'
           else tr.classificacao
           end                              classificacaotributo,
       case
           when valores.situacaolegal <> 0 and
                (valores.datadividaativa is null or valores.datadividaativa <= tep.dataestorno)
               then valores.situacaolegal
           else 0
           end                              situacaolegal,
       ttot.codigotce                    as tipooperacaodeducao,
       'ESTORNO_ACRESCIMOS_PARCELAMENTO' as tipomovimento,
       valores.iddebito,
       valores.iddebitoparcelareceita,
       valores.valor
from tribestornoparcelamento tep
         left join tribparcelamento tp on tep.idparcelamento = tp.idparcelamento
         left outer join tribparamparcelamento tpp
                         on tp.idparametroparcelamento = tpp.idparametroparcelamento
         left outer join tribmotivodesconto tmd
                         on tpp.motivodescontofinan = tmd.motivodesconto
         left outer join tribtipooperacaotce ttot
                         on tmd.idtipooperacaotce = ttot.idtipooperacaotce
         left join (select case
                               when x.parcela = x.max_parcela then
                                       x.valorjurosfinan  + x.juros_financiamento_extra -
                                       coalesce((select sum(y.rateio_juros_financiamento)
                                                 from vw_atualizacao_parcelamento y
                                                 where y.idparcelamento = x.idparcelamento
                                                   and y.iddebito = x.iddebito
                                                   and y.receitaorigem = x.receitaorigem
                                                   and y.parcela <> x.max_parcela), 0)
                               else x.rateio_juros_financiamento  + x.juros_financiamento_extra end as valor,
                           x.valorjurosfinan,
                           x.rateio_juros_financiamento,
                           x.idparcelamento,
                           x.iddebitoparcelareceita,
                           x.iddebito,
                           x.jurosfinandestino as receita,
                           x.guiarecolhimento,
                           x.situacaolegal,
                           x.datadividaativa
                      from vw_atualizacao_parcelamento x
                      where x.valorjurosfinan > 0
                      and x.dataestorno in (:datasMovimento)) as valores
                   on valores.idparcelamento = tp.idparcelamento
         left join tribdebito td on td.iddebito = valores.iddebito
         left join tribreceita tr
                   on tr.entidade = td.entidade  and tr.exercicio = :exercicio and tr.receita = valores.receita
where tep.dataestorno in (:datasMovimento)
  and valores.valor > 0
  and tp.anocontrato = :exercicio
  and (tep.datareabilitacao is null or tep.datareabilitacao != tep.dataestorno)
  and exists(select 1
             from tribestornoparcelamentodebito tepd
             where tepd.idestornoparcelamento = tep.idestornoparcelamento
               and tepd.iddebitoorigem < tepd.iddebitodestino)

==> portal-contribuinte-3.160.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/integracaocontabil/patrimonial/consulta-estorno-acrescimos-parcelamentos-para-proxima-subdivida.sql <==
select tp.entidade,
       tep.dataestorno as datamovimentacao,
       tr.receita as tributo,
       tr.descricao as descricaotributo,
       tr.tiporeceita as tipotributo,
       case
           when tr.classificacao = 'F'
               then 'J'
           else tr.classificacao
           end                              classificacaotributo,
       case
           when valores.situacaolegal <> 0 and
                (valores.datadividaativa is null or valores.datadividaativa <= tep.dataestorno)
               then valores.situacaolegal
           else 0
           end                              situacaolegal,
       ttot.codigotce                    as tipooperacaodeducao,
       'ESTORNO_ACRESCIMOS_PARCELAMENTO' as tipomovimento,
       valores.iddebito,
       valores.iddebitoparcelareceita,
       valores.valor
from tribestornoparcelamento tep
         left join tribparcelamento tp on tep.idparcelamento = tp.idparcelamento
         left outer join tribparamparcelamento tpp
                         on tp.idparametroparcelamento = tpp.idparametroparcelamento
         left outer join tribmotivodesconto tmd
                         on tpp.motivodescontofinan = tmd.motivodesconto
         left outer join tribtipooperacaotce ttot
                         on tmd.idtipooperacaotce = ttot.idtipooperacaotce
         left join (select case
                               when x.parcela = x.max_parcela then
                                       x.valorjurosfinan  + x.juros_financiamento_extra -
                                       coalesce((select sum(y.rateio_juros_financiamento)
                                                 from vw_atualizacao_parcelamento y
                                                 where y.idparcelamento = x.idparcelamento
                                                   and y.iddebito = x.iddebito
                                                   and y.receitaorigem = x.receitaorigem
                                                   and y.parcela <> x.max_parcela
                                                   and y.idestornoparcelamento = x.idestornoparcelamento), 0)
                               else x.rateio_juros_financiamento  + x.juros_financiamento_extra end as valor,
                           x.valorjurosfinan,
                           x.rateio_juros_financiamento,
                           x.idparcelamento,
                           x.iddebitoparcelareceita,
                           x.iddebito,
                           x.jurosfinandestino as receita,
                           x.guiarecolhimento,
                           x.situacaolegal,
                           x.datadividaativa
                      from vw_atualizacao_parcelamento x
                      where x.valorjurosfinan > 0
                      and x.dataestorno in (:datasMovimento)) as valores
                   on valores.idparcelamento = tp.idparcelamento
         left join tribdebito td on td.iddebito = valores.iddebito
         left join tribreceita tr
                   on tr.entidade = td.entidade  and tr.exercicio = :exercicio and tr.receita = valores.receita
where tep.dataestorno in (:datasMovimento)
  and valores.valor > 0
  and tp.anocontrato = :exercicio
  and (tep.datareabilitacao is null or tep.datareabilitacao != tep.dataestorno)
  and exists(select 1
             from tribestornoparcelamentodebito tepd
             where tepd.idestornoparcelamento = tep.idestornoparcelamento
               and tepd.iddebitoorigem < tepd.iddebitodestino)
